# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .test_suite_test_case_created_bulk_result import TestSuiteTestCaseCreatedBulkResult
from .test_suite_test_case_deleted_bulk_result import TestSuiteTestCaseDeletedBulkResult
from .test_suite_test_case_rejected_bulk_result import TestSuiteTestCaseRejectedBulkResult
from .test_suite_test_case_replaced_bulk_result import TestSuiteTestCaseReplacedBulkResult


class TestSuiteTestCaseBulkResult_Created(TestSuiteTestCaseCreatedBulkResult):
    type: typing.Literal["CREATED"] = "CREATED"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteTestCaseBulkResult_Replaced(TestSuiteTestCaseReplacedBulkResult):
    type: typing.Literal["REPLACED"] = "REPLACED"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteTestCaseBulkResult_Deleted(TestSuiteTestCaseDeletedBulkResult):
    type: typing.Literal["DELETED"] = "DELETED"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteTestCaseBulkResult_Rejected(TestSuiteTestCaseRejectedBulkResult):
    type: typing.Literal["REJECTED"] = "REJECTED"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


TestSuiteTestCaseBulkResult = typing.Union[
    TestSuiteTestCaseBulkResult_Created,
    TestSuiteTestCaseBulkResult_Replaced,
    TestSuiteTestCaseBulkResult_Deleted,
    TestSuiteTestCaseBulkResult_Rejected,
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .test_suite_test_case_create_bulk_operation_request import TestSuiteTestCaseCreateBulkOperationRequest
from .test_suite_test_case_delete_bulk_operation_request import TestSuiteTestCaseDeleteBulkOperationRequest
from .test_suite_test_case_replace_bulk_operation_request import TestSuiteTestCaseReplaceBulkOperationRequest


class TestSuiteTestCaseBulkOperationRequest_Create(TestSuiteTestCaseCreateBulkOperationRequest):
    type: typing.Literal["CREATE"] = "CREATE"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteTestCaseBulkOperationRequest_Replace(TestSuiteTestCaseReplaceBulkOperationRequest):
    type: typing.Literal["REPLACE"] = "REPLACE"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteTestCaseBulkOperationRequest_Delete(TestSuiteTestCaseDeleteBulkOperationRequest):
    type: typing.Literal["DELETE"] = "DELETE"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


TestSuiteTestCaseBulkOperationRequest = typing.Union[
    TestSuiteTestCaseBulkOperationRequest_Create,
    TestSuiteTestCaseBulkOperationRequest_Replace,
    TestSuiteTestCaseBulkOperationRequest_Delete,
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import pydantic_v1
from .search_result import SearchResult
from .workflow_node_result_event_state import WorkflowNodeResultEventState


class WorkflowResultEventOutputDataSearchResults(pydantic_v1.BaseModel):
    """
    A Search Results output streamed from a Workflow execution.
    """

    id: typing.Optional[str] = None
    name: str
    state: WorkflowNodeResultEventState
    node_id: str
    delta: typing.Optional[str] = pydantic_v1.Field(default=None)
    """
    The newly output string value. Only relevant for string outputs with a state of STREAMING.
    """

    value: typing.Optional[typing.List[SearchResult]] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import pydantic_v1
from .test_suite_run_deployment_release_tag_exec_config_data import TestSuiteRunDeploymentReleaseTagExecConfigData


class TestSuiteRunDeploymentReleaseTagExecConfig(pydantic_v1.BaseModel):
    """
    Execution configuration for running a Test Suite against a Prompt Deployment
    """

    data: TestSuiteRunDeploymentReleaseTagExecConfigData
    test_case_ids: typing.Optional[typing.List[str]] = pydantic_v1.Field(default=None)
    """
    Optionally specify a subset of test case ids to run. If not provided, all test cases within the test suite will be run by default.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
